leaftools.iterate_notes_and_chords_forward_in_expr
==================================================

.. autofunction:: abjad.tools.leaftools.iterate_notes_and_chords_forward_in_expr.iterate_notes_and_chords_forward_in_expr
